/*
    Copyright 2004,2005,2006 Luigi Auriemma

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

    http://www.gnu.org/licenses/gpl.txt

*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <windows.h>



#define VER         "0.1.1"
#define GOREXOR     "NONE"
#define KEYPATH     "Software\\4DRulers\\GoreUltimateSoldier"
#define BUFFSZ      512



void gore_keydec(u_char *data);



int main(void) {
    HKEY    key;
    u_char  buff[BUFFSZ];
    int     len;


    setbuf(stdout, NULL);

    fputs("\n"
        "Gore cd-key decoder "VER"\n"
        "by Luigi Auriemma\n"
        "e-mail: aluigi@autistici.org\n"
        "web:    aluigi.org\n"
        "\n", stdout);

    if(RegOpenKeyEx(HKEY_CURRENT_USER, KEYPATH, 0, KEY_READ, &key)) {
        fputs("\nError: registry key has not been found\n", stdout);
        fgetc(stdin);
        exit(1);
    }

    len = BUFFSZ;
    if(RegQueryValueEx(
      key,
      "cdkey",
      NULL,
      NULL,
      buff,
      (void *)&len)) {
        fputs("\nError: impossible to read the registry key\n", stdout);
        fgetc(stdin);
        exit(1);
    }
    RegCloseKey(key);

    printf("Encoded cd-key:   %s\n", buff);
    gore_keydec(buff);
    printf("Decoded cd-key:   %.4s-%.4s-%.4s-%.4s\n",
        buff,
        buff + 4,
        buff + 8,
        buff + 12);

    fgetc(stdin);
    return(0);
}



void gore_keydec(u_char *data) {
    u_char  *xorptr = GOREXOR;

    while(*data) {
        *data++ ^= *xorptr++;
        if(!*xorptr) xorptr = GOREXOR;
    }
}


